summaryrefslogtreecommitdiff
path: root/libavformat/internal.h
diff options
context:
space:
mode:
authorAnton Khirnov <anton@khirnov.net>2011-02-20 11:04:12 +0100
committerRonald S. Bultje <rsbultje@gmail.com>2011-02-20 08:37:15 -0500
commitae628ec1fd7f54c102bf9e667a3edd404b9b9128 (patch)
treee23e5873e32189d50147e7a73956e326f3f1e407 /libavformat/internal.h
parent70aa916e4630bcec14439a2d703074b6d4c890a8 (diff)
avio: rename ByteIOContext to AVIOContext.
Signed-off-by: Ronald S. Bultje <rsbultje@gmail.com>
Diffstat (limited to 'libavformat/internal.h')
-rw-r--r--libavformat/internal.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/libavformat/internal.h b/libavformat/internal.h
index 16aa0af189..02a27e4724 100644
--- a/libavformat/internal.h
+++ b/libavformat/internal.h
@@ -157,20 +157,20 @@ int ff_get_v_length(uint64_t val);
/**
* Put val using a variable number of bytes.
*/
-void ff_put_v(ByteIOContext *bc, uint64_t val);
+void ff_put_v(AVIOContext *bc, uint64_t val);
/**
* Read a whole line of text from ByteIOContext. Stop reading after reaching
* either a \n, a \0 or EOF. The returned string is always \0 terminated,
* and may be truncated if the buffer is too small.
*
- * @param s the read-only ByteIOContext
+ * @param s the read-only AVIOContext
* @param buf buffer to store the read line
* @param maxlen size of the buffer
* @return the length of the string written in the buffer, not including the
* final \0
*/
-int ff_get_line(ByteIOContext *s, char *buf, int maxlen);
+int ff_get_line(AVIOContext *s, char *buf, int maxlen);
#define SPACE_CHARS " \t\r\n"
@@ -157,20 +157,20 @@ int ff_get_v_length(uint64_t val);
/**
- * Read a whole line of text from ByteIOContext. Stop reading after reaching
+ * Read a whole line of text from AVIOContext. Stop reading after reaching
* either a \n, a \0 or EOF. The returned string is always \0 terminated,
* and may be truncated if the buffer is too small.